@@ -1,10 +1,9 @@
 #!/usr/bin/env python
-import sys, imp, re
-sys.path[:0] = [".."]
+import imp, re
 import pyx
 from pyx import *
 
-text.set(mode="latex")
+text.set(text.LatexRunner)
 text.preamble(r"\renewcommand{\familydefault}{\ttdefault}")
 c = canvas.canvas()
 
