@@ -1,10 +1,10 @@
 # -*- encoding: utf-8 -*-
 #
 #
-# Copyright (C) 2005-2011 Jörg Lehmann <joergl@users.sourceforge.net>
-# Copyright (C) 2005-2011 André Wobst <wobsta@users.sourceforge.net>
+# Copyright (C) 2005-2011 Jörg Lehmann <joerg@pyx-project.org>
+# Copyright (C) 2005-2011 André Wobst <wobsta@pyx-project.org>
 #
-# This file is part of PyX (http://pyx.sourceforge.net/).
+# This file is part of PyX (https://pyx-project.org/).
 #
 # PyX is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 
 import logging, sys
-from . import bbox, pswriter, pdfwriter, writer, trafo, style, unit
+from . import bbox, pswriter, pdfwriter, svgwriter, trafo, style, unit
 
 logger = logging.getLogger("pyx")
 
@@ -121,7 +121,9 @@ class page:
         else:
             cc = self.canvas
 
-        getattr(style.linewidth.normal, processMethod)(contentfile, writer, context, registry)
+        if processMethod != "processSVG":
+            # for SVG we write the pyx defaults as part of the svg node attributes in the writer
+            getattr(style.linewidth.normal, processMethod)(contentfile, writer, context, registry)
         if self.pagebbox:
             bbox = bbox.copy() # don't alter the bbox provided to the constructor -> use a copy
         getattr(cc, processMethod)(contentfile, writer, context, registry, bbox)
@@ -132,6 +134,9 @@ class page:
     def processPDF(self, *args):
         self._process("processPDF", *args)
 
+    def processSVG(self, *args):
+        self._process("processSVG", *args)
+
 
 class _noclose:
 
@@ -187,10 +192,15 @@ class document:
         with _outputstream(file, "pdf") as f:
             pdfwriter.PDFwriter(self, f, **kwargs)
 
+    def writeSVGfile(self, file=None, **kwargs):
+        with _outputstream(file, "svg") as f:
+            svgwriter.SVGwriter(self, f, **kwargs)
+
     def writetofile(self, filename, **kwargs):
         for suffix, method in [("eps", pswriter.EPSwriter),
                                ("ps", pswriter.PSwriter),
-                               ("pdf", pdfwriter.PDFwriter)]:
+                               ("pdf", pdfwriter.PDFwriter),
+                               ("svg", svgwriter.SVGwriter)]:
             if filename.endswith(".{}".format(suffix)):
                 with open(filename, "wb") as f:
                     method(self, f, **kwargs)
